## Summary

A critical review is a form of research synthesis that rigorously evaluates existing literature to identify weaknesses, contradictions, and inconsistencies. It assesses each piece of literature against specific criteria to gauge its adequacy, thereby highlighting areas where current knowledge may be unreliable. This approach aids in directing future research by pinpointing specific problems and discrepancies that need to be addressed. Critical reviews are typically either selective or representative in nature, often omitting a comprehensive literature search, and may use various data synthesis methods rooted in either positivist or interpretivist epistemological positions.

If the focus is on research methods, a [critical methodological review](colrev.methodological_review.html) may be appropriate.

## Characteristics

| Dimension                  | Description                                    |
|----------------------------|------------------------------------------------|
| Goal with regard to theory | Understanding                                  |
| Scope of questions         | Broad                                          |
| Nature of sources          | Conceptual and  empirical papers               |

## Data extraction, analysis, and synthesis

The following packages are automatically set up in a critical review:

- [colrev.prisma](colrev.prisma.html)
- [colrev.paper_md](colrev.paper_md.html)

## Examples

Bélanger, F., & Crossler, R. E. (2011). Privacy in the digital age: a review of information privacy research in information systems. MIS Quarterly, 35(4), 1017-1041. doi:[10.2307/41409971](https://doi.org/10.2307/41409971)

Jones, M. R., & Karsten, H. (2008). Giddens's structuration theory and information systems research. MIS Quarterly, 32(1), 127-157. doi:[10.2307/25148831
](https://doi.org/10.2307/25148831)

## Methods papers

Paré, G., Trudel, M. C., Jaana, M., & Kitsiou, S. (2015). Synthesizing information systems knowledge: A typology of literature reviews. Information & Management, 52(2), 183-199. doi:[10.1016/j.im.2014.08.008](https://doi.org/10.1016/j.im.2014.08.008)
